@@ -158,9 +158,37 @@ class Normals(Base):
         if self._stations.size == 0 or self._data.size == 0:
             return None
 
+        def adjust_temp(data: pd.DataFrame):
+            """
+            Adjust temperature-like data based on altitude
+            """
+
+            data.loc[data['tmin'] != np.NaN, 'tmin'] = data['tmin'] + \
+                ((2 / 3) * ((data['elevation'] - alt) / 100))
+            data.loc[data['tmax'] != np.NaN, 'tmax'] = data['tmax'] + \
+                ((2 / 3) * ((data['elevation'] - alt) / 100))
+
+            return data
+
         if method == 'nearest':
 
-            self._data = self._data.groupby(level=[
+            if adapt_temp:
+
+                # Join elevation of involved weather stations
+                data = self._data.join(
+                    stations['elevation'], on='station')
+
+                # Adapt temperature-like data based on altitude
+                data = adjust_temp(data)
+
+                # Drop elevation & round
+                data = data.drop('elevation', axis=1).round(1)
+
+            else:
+
+                data = self._data
+
+            self._data = data.groupby(level=[
                 'start',
                 'end',
                 'month'
@@ -173,10 +201,7 @@ class Normals(Base):
 
             # Adapt temperature-like data based on altitude
             if adapt_temp:
-                data.loc[data['tmin'] != np.NaN, 'tmin'] = data['tmin'] + \
-                    ((2 / 3) * ((data['elevation'] - alt) / 100))
-                data.loc[data['tmax'] != np.NaN, 'tmax'] = data['tmax'] + \
-                    ((2 / 3) * ((data['elevation'] - alt) / 100))
+                data = adjust_temp(data)
 
             # Aggregate mean data
             data = data.groupby(level=[
@@ -285,7 +310,12 @@ class Normals(Base):
                     ['station', 'start', 'end', 'month'], inplace=True)
                 # Merge data
                 temp._data = pd.concat([temp._data, df], axis=0).groupby(
-                    ['station', 'start', 'end', 'month'], as_index=True).first()
+                    [
+                        'station',
+                        'start',
+                        'end',
+                        'month'
+                    ], as_index=True).first() if temp._data.index.size > 0 else df
 
         # None -> NaN
         temp._data = temp._data.fillna(np.NaN)
